emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 225b426f256: ; Fix typos


From: Stefan Kangas
Subject: emacs-29 225b426f256: ; Fix typos
Date: Mon, 27 May 2024 04:11:58 -0400 (EDT)

branch: emacs-29
commit 225b426f256ba00aff7669ad18a5c85f86e22f67
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos
---
 ChangeLog.3                         |  8 ++++----
 ChangeLog.4                         | 40 ++++++++++++++++++-------------------
 admin/notes/www                     |  2 +-
 lisp/eshell/esh-util.el             |  6 +++---
 lisp/filesets.el                    |  2 +-
 lisp/leim/quail/persian.el          |  2 +-
 lisp/shell.el                       |  2 +-
 lisp/simple.el                      |  2 +-
 lisp/textmodes/table.el             |  8 ++++----
 lisp/vc/diff-mode.el                |  2 +-
 src/w32font.c                       |  2 +-
 test/lisp/emacs-lisp/icons-tests.el |  2 +-
 test/lisp/progmodes/python-tests.el |  4 ++--
 13 files changed, 41 insertions(+), 41 deletions(-)

diff --git a/ChangeLog.3 b/ChangeLog.3
index d43ffa10bc7..21c4a092be0 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -6427,7 +6427,7 @@
        * lisp/net/tramp-fuse.el (tramp-fuse-mount-timeout): New defconst.
        (tramp-fuse-mounted-p): Use it.  Check for a file property instead
        of a connection property.
-       (tramp-fuse-unmount): Dito.
+       (tramp-fuse-unmount): Ditto.
 
        * lisp/net/tramp-sshfs.el (tramp-sshfs-maybe-open-connection):
        Do not trust existence of a process, whether the volume is mounted.
@@ -11209,7 +11209,7 @@
        (flymake--publish-diagnostics): Helper for flymake--handle-report.
        (flymake--mode-line-counter, flymake-show-diagnostic)
        (flymake--diagnostics-buffer-entries): Use
-       flymake-diagnostic-buffer, flymake-diagonstic-type,
+       flymake-diagnostic-buffer, flymake-diagnostic-type,
        flymake-diagnostic-beg.
 
 2021-09-14  João Távora  <joaotavora@gmail.com>
@@ -137530,7 +137530,7 @@
        Bind `enable-local-variables' in `hack-connection-local-variables'
 
        * lisp/files-x.el (hack-connection-local-variables):
-       Bind `enable-local-variables', instead of re-declaring
+       Bind `enable-local-variables', instead of redeclaring
        `safe-local-variable-p'.
 
 2019-03-23  Eli Zaretskii  <eliz@gnu.org>
@@ -163179,7 +163179,7 @@
 
        Quieten compilation of octave.el
 
-       * lisp/progmodes/octave.el (compilation-forget-errors): Re-declare.
+       * lisp/progmodes/octave.el (compilation-forget-errors): Redeclare.
 
 2018-02-28  Glenn Morris  <rgm@gnu.org>
 
diff --git a/ChangeLog.4 b/ChangeLog.4
index 4b806c21124..d9596005f70 100644
--- a/ChangeLog.4
+++ b/ChangeLog.4
@@ -1319,7 +1319,7 @@
 
        Fix c-ts-mode indentation (bug#67357)
 
-       1. In a compund_statement, we indent the first sibling against the
+       1. In a compound_statement, we indent the first sibling against the
        parent, and the rest siblings against their previous sibling.  But
        this strategy falls apart when the first sibling is not on its own
        line.  We should regard the first sibling that is on its own line as
@@ -11284,7 +11284,7 @@
 
        Add array_initializer to java-ts-mode
 
-       Indent strings inside arrray_initializer one step:
+       Indent strings inside array_initializer one step:
 
        public class Java {
            void foo() {
@@ -16406,7 +16406,7 @@
        config-format[1] through a new major-mode: toml-ts-mode.
 
        I've read through the full spec[2], and from what I can see this
-       major-mode should provide correct syntax-highligting for every sort of
+       major-mode should provide correct syntax highlighting for every sort of
        config-declaration which adheres to the specification.
 
        Besides that it also adds support for imenu and basic tree-sitter
@@ -26568,7 +26568,7 @@
        option.
        (package-vc-archive-spec-alist): Add new variable to store the
        contents of 'elpa-packages' for each archive.
-       (pacakge-vc-desc->spec): Add function to query package specifications.
+       (package-vc-desc->spec): Add function to query package specifications.
        (package-vc--read-archive-data): Add a 'package-read-archive-hook'
        implementation.
        (package-vc--download-and-read-archives): Add a
@@ -34210,7 +34210,7 @@
 
 2022-09-15  Mattias Engdegård  <mattiase@acm.org>
 
-       Include nil as valid wallpaper-commmand
+       Include nil as valid wallpaper-command
 
        * lisp/image/wallpaper.el (wallpaper-command):
        Include nil in the type since that is a valid value for the variable,
@@ -44103,7 +44103,7 @@
 
        * src/bytecode.c (exec_byte_code):
        * lisp/emacs-lisp/comp.el (comp-limplify-lap-inst):
-       * lisp/emacs-lisp/bytecomp.el: Restore the statu quo ante.
+       * lisp/emacs-lisp/bytecomp.el: Restore the status quo ante.
 
        * etc/NEWS: Remove the entry about the new optional argument.
 
@@ -52809,7 +52809,7 @@
          /emacs/configure: line 18002: syntax error near unexpected token `;;'
          /emacs/configure: line 18002: `  ;;'
        That is due to under-quoting of AC_CHECK_LIB's second argument, which 
led to
-       the comma in an embedded string being interpreted as 
paramater-delimiting.
+       the comma in an embedded string being interpreted as 
parameter-delimiting.
        * configure.ac: Quote the second arg of each AC_CHECK_LIB invocation.
        (Bug#56272)
 
@@ -62459,7 +62459,7 @@
        up-to-date) until the next invocation of 'eglot-flymake-backend'.
 
        For now, this doesn't affect Flymake "list-only" diagnostics.  Those
-       are reported via the 'flymake-list-only-diagonstics' variable and
+       are reported via the 'flymake-list-only-diagnostics' variable and
        are always communicated immediately to it.
 
        * eglot.el: (eglot-handle-notification
@@ -66876,7 +66876,7 @@
        (eshell-get-delimited-modifier-argument): New functions...
        (eshell-pred-user-or-group, eshell-pred-file-time)
        (eshell-pred-file-links, eshell-pred-file-size)
-       (eshell-pred-substitute, eshell-join-memebers, eshell-split-members):
+       (eshell-pred-substitute, eshell-join-members, eshell-split-members):
        ... and use them here.
        (eshell-include-members): Pass 'mod-char' and use
        'eshell-get-delimited-modifier-argument'.
@@ -74587,7 +74587,7 @@
 
 2022-03-24  Jimmy Aguilar Mena  <spacibba@aol.com>
 
-       Merge 'completion-auto-select new value secont-tab'
+       Merge 'completion-auto-select new value second-tab'
 
        This includes the second-tab value for completion-auto-select and
        documentation related.
@@ -82366,7 +82366,7 @@
 
 2022-02-06  Wang Chunye  <chunywan@xilinx.com>  (tiny change)
 
-       optimization: constand folding for read-kbd-macro
+       optimization: constant folding for read-kbd-macro
 
        to boost startup performance, it is better to avoid invoking
        `read-kbd-macro` at run time which requires 'cl-lib.
@@ -83611,7 +83611,7 @@
        symbols since the rest is now available from `function-history`.
        * src/eval.c (un_autoload): Adjust accordingly.
 
-       * src/lread.c (load-history): Udate docstring.
+       * src/lread.c (load-history): Update docstring.
 
        * lisp/loadhist.el (loadhist-unload-filename): New var.
        (unload-feature): Bind it.
@@ -102240,7 +102240,7 @@
 
 2021-11-06  Lars Ingebrigtsen  <larsi@gnus.org>
 
-       Remove too-agressive window refresh in the hourglass code
+       Remove too aggressive window refresh in the hourglass code
 
        * src/xterm.c (x_show_hourglass): Don't force a spurious refresh
        (bug#51649).
@@ -110715,7 +110715,7 @@
 
 2020-11-21  Yuuki Harano  <masm+github@masm11.me>
 
-       Implement Scroll-bar-forground and scroll-bar-background
+       Implement scroll-bar-foreground and scroll-bar-background
 
        * src/pgtkterm.h (struct pgtk_output):
 
@@ -112654,7 +112654,7 @@
        Rework and correct major part of xref glue code
 
        See comments of https://github.com/joaotavora/eglot/pull/314.  Up to
-       now, xref-backend-indentifier-completion-table was a gross hack that
+       now, xref-backend-identifier-completion-table was a gross hack that
        only worked sometimes.  It relied on some fugly gymnastics to cache a
        response from :textDocument/documentSymbol and somehow used that
        information to build a completion table.  But it doesn't work well.
@@ -113087,12 +113087,12 @@
 
        Merge pull request from stribb/master
 
-       Add a line of documentation for (use-pacakage ... :hook).
+       Add a line of documentation for (use-package ... :hook).
        GitHub-reference: https://github.com/jwiegley/use-package/issues/759
 
 2019-04-04  Andrew Stribblehill  <stribb@gmail.com>  (tiny change)
 
-       Add a line of documentation for (use-pacakage ... :hook)
+       Add a line of documentation for (use-package ... :hook)
 
 2019-02-13  João Távora  <joaotavora@gmail.com>
 
@@ -113770,7 +113770,7 @@
 
        Fix potential security issue fontifying lsp doc
 
-       Previously, a server could mistankely or maliciously call *-mode
+       Previously, a server could mistakenly or maliciously call *-mode
        functions by in the response to a completion or hover request,
        specifically in the :documentation field of the response.
 
@@ -115537,7 +115537,7 @@
        Also cquery sometimes send 0-length ranges upon which we now fallback
        to flymake-diag-region.
 
-       Finally, in eglot-eldoc-funciton, the previous hack of calling the
+       Finally, in eglot-eldoc-function, the previous hack of calling the
        eglot--hover-info outside of the when-buffer-window macrolet contained
        a bug. It must be called in the correct buffer. Revert the hack and do
        it by querying from eglot.el if ert is running tests.
@@ -119347,7 +119347,7 @@
 
            (use-package foopkg :bind "<some-key>")
 
-       intendes to bind <some-key> to 'foopkg command.
+       intends to bind <some-key> to 'foopkg command.
 
 2016-10-31  Noam Postavsky  <npostavs@gmail.com>
 
diff --git a/admin/notes/www b/admin/notes/www
index 0a2d4aa9859..f22eff8f4c7 100644
--- a/admin/notes/www
+++ b/admin/notes/www
@@ -85,7 +85,7 @@ permanent redirects, and changes go live more-or-less 
straight away.
 This method is useful for making cross-references to non-Emacs manuals
 work; see manual/.htaccess in the repository.  You only have to add a
 single redirect for every given external manual, you can redirect
-html_node to hmtl_node and html_mono to html_mono.
+html_node to html_node and html_mono to html_mono.
 
 * Why CVS?
 
diff --git a/lisp/filesets.el b/lisp/filesets.el
index 0b97bd4c518..3f7e078abb0 100644
--- a/lisp/filesets.el
+++ b/lisp/filesets.el
@@ -1654,7 +1654,7 @@ Assume MODE (see `filesets-entry-mode'), if provided."
                  (cons entry (filesets-ingroup-cache-get entry))))
               (:tree
                 ;; Warning: ENTRY here could be of at least two
-                ;; differente forms, either
+                ;; different forms, either
                 ;;    (NAME (:tree DIRECTORY PATTERN))
                 ;; or
                 ;;    (DIRECTORY PATTERN)
diff --git a/lisp/leim/quail/persian.el b/lisp/leim/quail/persian.el
index de61481d7f1..676b3ab5c2e 100644
--- a/lisp/leim/quail/persian.el
+++ b/lisp/leim/quail/persian.el
@@ -500,7 +500,7 @@
  ;; RIGHT-TO-LEFT EMBEDDING (sets base dir to RTL but allows embedded text)
  ("&rle;" ?\u202B)   ;; (ucs-insert #x202B)   named: زیرمتنِ راست‌به‌چپ
  ;; POP DIRECTIONAL FORMATTING (used for RLE or LRE and RLO or LRO)
- ;; EMACS ANOMOLY --- Why does &pdf not show up in (describe-input-method 
'farsi-transliterate-banan)
+ ;; EMACS ANOMALY --- Why does &pdf not show up in (describe-input-method 
'farsi-transliterate-banan)
  ("&pdf;" ?\u202C)   ;; (ucs-insert #x202C)   named: پایانِ زیرمتن
  ("P" ?\u202C)
  ;; LEFT-TO-RIGHT OVERRIDE (overrides the bidirectional algorithm, display LTR)
diff --git a/lisp/shell.el b/lisp/shell.el
index ca86059f9de..373153f9b0c 100644
--- a/lisp/shell.el
+++ b/lisp/shell.el
@@ -37,7 +37,7 @@
 ;; the hooks available for customizing it, see the file comint.el.
 ;; For further information on shell mode, see the comments below.
 
-;; Needs fixin:
+;; Needs fixing:
 ;; When sending text from a source file to a subprocess, the process-mark can
 ;; move off the window, so you can lose sight of the process interactions.
 ;; Maybe I should ensure the process mark is in the window when I send
diff --git a/lisp/simple.el b/lisp/simple.el
index d91efb23363..452c2ab2a5b 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -4505,7 +4505,7 @@ a shell (with its need to quote arguments)."
                                 (dired-get-filename nil t)))))
                          (and filename (file-relative-name filename))))
     nil
-    ;; FIXME: the following argument is always ignored by 'shell-commnd',
+    ;; FIXME: the following argument is always ignored by 'shell-command',
     ;; when the command is invoked asynchronously, except, perhaps, when
     ;; 'default-directory' is remote.
     shell-command-default-error-buffer))
diff --git a/lisp/textmodes/table.el b/lisp/textmodes/table.el
index 973f589b204..2c0f918b0de 100644
--- a/lisp/textmodes/table.el
+++ b/lisp/textmodes/table.el
@@ -4134,7 +4134,7 @@ cache buffer into the designated cell in the table 
buffer."
                 (currentp (equal cell-coord current-cell-coordinate)))
            (if currentp (table--goto-coordinate current-coordinate)
              (table--goto-coordinate (car cell-coord)))
-           (table-recognize-cell 'froce)
+           (table-recognize-cell 'force)
            (let ((table-inhibit-update t))
              (table-with-cache-buffer
                (let ((sticky (and currentp
@@ -4147,7 +4147,7 @@ cache buffer into the designated cell in the table 
buffer."
            (table--update-cell 'now)
            ))
        (table--goto-coordinate current-coordinate)
-       (table-recognize-cell 'froce)))))
+       (table-recognize-cell 'force)))))
 
 (defun table--update-cell-heightened (&optional now)
   "Update the contents of the cells that are affected by heightening 
operation."
@@ -4176,7 +4176,7 @@ cache buffer into the designated cell in the table 
buffer."
                 (currentp (equal cell-coord current-cell-coordinate)))
            (if currentp (table--goto-coordinate current-coordinate)
              (table--goto-coordinate (car cell-coord)))
-           (table-recognize-cell 'froce)
+           (table-recognize-cell 'force)
            (let ((table-inhibit-update t))
              (table-with-cache-buffer
                (let ((sticky (and currentp
@@ -4189,7 +4189,7 @@ cache buffer into the designated cell in the table 
buffer."
            (table--update-cell 'now)
            ))
        (table--goto-coordinate current-coordinate)
-       (table-recognize-cell 'froce)))))
+       (table-recognize-cell 'force)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
diff --git a/lisp/vc/diff-mode.el b/lisp/vc/diff-mode.el
index 4f150dc7f36..f93659be02d 100644
--- a/lisp/vc/diff-mode.el
+++ b/lisp/vc/diff-mode.el
@@ -2640,7 +2640,7 @@ fixed, visit it in a buffer."
                 (?- . (left-fringe diff-fringe-del diff-indicator-removed))
                 (?! . (left-fringe diff-fringe-rep diff-indicator-changed))
                 (?\s . (left-fringe diff-fringe-nul fringe)))))))))
-    ;; Mimicks the output of Magit's diff.
+    ;; Mimics the output of Magit's diff.
     ;; FIXME: This has only been tested with Git's diff output.
     ;; FIXME: Add support for Git's "rename from/to"?
     (while (re-search-forward "^diff " limit t)
diff --git a/src/w32font.c b/src/w32font.c
index f2d4e5e45e8..70cfdd6bbe1 100644
--- a/src/w32font.c
+++ b/src/w32font.c
@@ -430,7 +430,7 @@ w32font_encode_char (struct font *font, int c)
 }
 
 /* w32 implementation of text_extents for font backend.
-   Perform the size computation of glyphs of FONT and fillin members
+   Perform the size computation of glyphs of FONT and fill in members
    of METRICS.  The glyphs are specified by their glyph codes in
    CODE (length NGLYPHS).  Apparently metrics can be NULL, in this
    case just return the overall width.  */
diff --git a/test/lisp/emacs-lisp/icons-tests.el 
b/test/lisp/emacs-lisp/icons-tests.el
index fa320a49866..d3bf63b2b60 100644
--- a/test/lisp/emacs-lisp/icons-tests.el
+++ b/test/lisp/emacs-lisp/icons-tests.el
@@ -54,7 +54,7 @@
     (enable-theme 'test-icons-theme)
     (should (equal (icon-string 'icon-test1) "<"))))
 
-(ert-deftest test-icon-inheretance ()
+(ert-deftest test-icon-inheritance ()
   (let ((icon-preference '(image emoji symbol text)))
     (should (equal (icon-string 'icon-test2) ">")))
   (let ((icon-preference '(text)))
diff --git a/test/lisp/progmodes/python-tests.el 
b/test/lisp/progmodes/python-tests.el
index 06943e22f5b..66eb4e7a29d 100644
--- a/test/lisp/progmodes/python-tests.el
+++ b/test/lisp/progmodes/python-tests.el
@@ -7159,12 +7159,12 @@ always located at the beginning of buffer."
      (forward-to-word 1)
      (should (eq (face-at-point) font-lock-keyword-face)))))
 
-(ert-deftest python-ts-mode-named-assignement-face-1 ()
+(ert-deftest python-ts-mode-named-assignment-face-1 ()
   (python-ts-tests-with-temp-buffer
    "var := 3"
    (should (eq (face-at-point) font-lock-variable-name-face))))
 
-(ert-deftest python-ts-mode-assignement-face-2 ()
+(ert-deftest python-ts-mode-assignment-face-2 ()
   (python-ts-tests-with-temp-buffer
    "var, *rest = call()"
    (dolist (test '("var" "rest"))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/eshell/esh-util.el b/lisp/eshell/esh-util.el
index 163577f5d08..6abb2127e7b 100644
--- a/lisp/eshell/esh-util.el
+++ b/lisp/eshell/esh-util.el
@@ -200,7 +200,7 @@ doubling it up."
 
 (defun eshell-convertible-to-number-p (string)
   "Return non-nil if STRING can be converted to a number.
-If `eshell-convert-numeric-aguments', always return nil."
+If `eshell-convert-numeric-arguments', always return nil."
   (and eshell-convert-numeric-arguments
        (string-match
         (concat "\\`\\s-*" eshell-number-regexp "\\s-*\\'")
@@ -209,7 +209,7 @@ If `eshell-convert-numeric-aguments', always return nil."
 (defun eshell-convert-to-number (string)
   "Try to convert STRING to a number.
 If STRING doesn't look like a number (or
-`eshell-convert-numeric-aguments' is nil), just return STRING
+`eshell-convert-numeric-arguments' is nil), just return STRING
 unchanged."
   (if (eshell-convertible-to-number-p string)
       (string-to-number string)
@@ -224,7 +224,7 @@ trailing newlines removed.  Otherwise, this behaves as 
follows:
 
 * Split multiline strings by line.
 
 * If `eshell-convert-numeric-aguments' is non-nil and every line
   of output looks like a number, convert them to numbers."
   (cond
    ((not (stringp string))
@@ -224,7 +224,7 @@ trailing newlines removed.  Otherwise, this behaves as 
 * Split multiline strings by line.
 
-* If `eshell-convert-numeric-aguments' is non-nil and every line
+* If `eshell-convert-numeric-arguments' is non-nil and every line
   of output looks like a number, convert them to numbers."
   (cond